
import React from 'react';
import ReactDOM from 'react-dom/client';
import { BrowserRouter } from 'react-router-dom';
import { HelmetProvider } from 'react-helmet-async';
import App from './App.tsx';
import './index.css';
import './styles/accessibility/index.css';
import './styles/optimized-animations.css';
import './styles/images.css';
import { initializePerformanceOptimizations } from './utils/performance/core';

// Mark the start time for performance measurement
const startTime = performance.now();

// Optimisation LCP simplifiée - Ne précharge que l'image de la homepage
const optimizeCriticalLCP = () => {
  // Créer une promesse simple pour suivre l'état de chargement
  window.lcpLoaded = new Promise<boolean>((resolve) => {
    window.lcpLoadedResolve = resolve;
  });
  
  // Récupérer le chemin actuel pour décider quelle image précharger
  const currentPath = window.location.pathname;
  
  // Image par défaut pour la homepage
  let lcpImagePath = '/lovable-uploads/1a84b2a9-9195-4c59-a470-64cc63cb9b51.png';
  
  // Différentes images pour différentes pages
  if (currentPath === '/prestation') {
    lcpImagePath = '/lovable-uploads/5e71cb9d-52e2-4eb1-8099-3e0e07657e31.png';
  }
  // Ajouter d'autres conditions pour d'autres pages si nécessaire
  
  // Précharger l'image LCP en priorité absolue
  const isMobile = window.innerWidth < 768;
  const imageWidth = isMobile ? 480 : 800;
  const imageQuality = isMobile ? 40 : 60;
  
  const lcpImageUrl = `${lcpImagePath}?w=${imageWidth}&q=${imageQuality}&fmt=webp`;
  
  const link = document.createElement('link');
  link.rel = 'preload';
  link.as = 'image';
  link.href = lcpImageUrl;
  link.fetchPriority = 'high';
  document.head.appendChild(link);
  
  // Créer un élément image dans le DOM pour démarrer le chargement immédiatement
  const preloadImage = new Image();
  preloadImage.src = lcpImageUrl;
  preloadImage.fetchPriority = 'high';
  preloadImage.decoding = 'async';
  preloadImage.onload = () => {
    // Résoudre la promesse dès que l'image est chargée
    if (window.lcpLoadedResolve) {
      window.lcpLoadedResolve(true);
      console.log('LCP image loaded at ' + (performance.now() - startTime) + 'ms');
    }
  };
};

// Exécuter l'optimisation LCP IMMÉDIATEMENT avant tout autre code
optimizeCriticalLCP();

// Initialize core performance optimizations
initializePerformanceOptimizations();

// Render the app without delay
const root = ReactDOM.createRoot(document.getElementById('root')!);
root.render(
  process.env.NODE_ENV === 'development' ? (
    <React.StrictMode>
      <HelmetProvider>
        <BrowserRouter>
          <App />
        </BrowserRouter>
      </HelmetProvider>
    </React.StrictMode>
  ) : (
    <HelmetProvider>
      <BrowserRouter>
        <App />
      </BrowserRouter>
    </HelmetProvider>
  ),
);

// Log performance metrics when page is loaded
window.addEventListener('load', () => {
  const loadTime = performance.now() - startTime;
  if (process.env.NODE_ENV === 'development') {
    console.log(`Page chargée en ${loadTime.toFixed(2)}ms`);
  }
  
  // Mesurer le LCP spécifiquement
  if ('PerformanceObserver' in window) {
    new PerformanceObserver((entryList) => {
      const entries = entryList.getEntries();
      const lastEntry = entries[entries.length - 1];
      if (lastEntry) {
        const lcpTime = lastEntry.startTime;
        console.log(`LCP: ${lcpTime.toFixed(2)}ms`);
      }
    }).observe({ type: 'largest-contentful-paint', buffered: true });
  }
}, { passive: true });

// Déplacer toutes les initialisations non critiques APRÈS le chargement de la page
window.addEventListener('load', () => {
  // Attendre 1 seconde après le chargement de la page pour initialiser les fonctionnalités non critiques
  setTimeout(() => {
    // Initialiser le consentement aux cookies
    const initializeCookieConsent = () => {
      console.log('Initialisation du système de consentement des cookies');
      // Vérifier les consentements existants
      const cookieConsent = localStorage.getItem('cookie-consent');
      
      if (cookieConsent) {
        try {
          const parsedConsent = JSON.parse(cookieConsent);
          console.log('Consentements sauvegardés:', parsedConsent);
        } catch (e) {
          console.error('Erreur lors du parsing du consentement:', e);
        }
      } else {
        console.log('Aucun consentement trouvé, affichage de la bannière mais tracking actif par défaut');
      }
    };
    
    // Initialiser les pixels de tracking et autres fonctionnalités non critiques
    const initializeTracking = () => {
      if ('requestIdleCallback' in window) {
        requestIdleCallback(() => {
          import('./utils/tracking/meta/initialization').then(({ initializeMetaPixel }) => {
            initializeMetaPixel();
          }).catch(err => {
            console.error('Failed to load Meta Pixel initialization:', err);
          });
        });
      } else {
        setTimeout(() => {
          import('./utils/tracking/meta/initialization').then(({ initializeMetaPixel }) => {
            initializeMetaPixel();
          }).catch(err => {
            console.error('Failed to load Meta Pixel initialization:', err);
          });
        }, 2000);
      }
    };
    
    // Exécuter les initialisations non critiques
    initializeCookieConsent();
    initializeTracking();
    
    // Précharger d'autres ressources moins critiques
    const preloadSecondaryResources = () => {
      if ('requestIdleCallback' in window) {
        requestIdleCallback(() => {
          const secondaryImages = [
            // Ajouter ici d'autres images importantes mais non critiques
          ];
          
          secondaryImages.forEach(url => {
            const link = document.createElement('link');
            link.rel = 'prefetch';
            link.as = 'image';
            link.href = url;
            document.head.appendChild(link);
          });
        }, { timeout: 5000 });
      }
    };
    
    preloadSecondaryResources();
    
  }, 1000);
}, { passive: true });
